@@ -7,10 +7,6 @@
 #'                labels back to subsetted data frames that have been subsetted, for instance,
 #'                with \code{\link{subset}}.
 #'
-#' @seealso \href{http://www.strengejacke.de/sjPlot/labelleddata/}{sjPlot-manual}
-#'            on working with labelled data, and \code{\link{remove_all_labels}} for
-#'            removing label attributes from data frames.
-#'
 #' @param df_new The new, subsetted data frame.
 #' @param df_origin The original data frame where the subset (\code{df_new}) stems from;
 #'          use \code{NULL}, if value and variable labels from \code{df_new} should be removed.
@@ -18,8 +14,8 @@
 #'           (if \code{df_origin = NULL}) or with copied value and variable label
 #'           attributes (if \code{df_origin} was the original subsetted data frame).
 #'
-#' @note In case \code{df_origin = NULL}, all possible label attributes
-#'         from \code{df_new} are removed.
+#' @note This function is deprecated. Please use \CRANpkg{sjlabelled} for
+#'       labelled data functions now.
 #'
 #' @examples
 #' data(efc)
@@ -32,15 +28,17 @@
 #' efc.sub <- copy_labels(efc.sub)
 #' str(efc.sub)
 #'
+#' @importFrom sjlabelled remove_all_labels set_labels get_labels get_label set_label
 #' @export
 copy_labels <- function(df_new, df_origin = NULL) {
+  .Deprecated("copy_labels", package = "sjlabelled", msg = "This function will be removed in future versions of sjmisc and has been moved to package 'sjlabelled'. Please use sjlabelled::copy_labels() instead.")
   # check if old df is NULL. if so, we remove all labels
   # from the data frame.
   if (is.null(df_origin)) {
     # tell user
     message("Removing all variable and value labels from data frame.")
     # remove all labels
-    df_new <- remove_all_labels(df_new)
+    df_new <- sjlabelled::remove_all_labels(df_new)
   } else {
     # check params
     if (is.data.frame(df_new) && is.data.frame(df_origin)) {
@@ -58,12 +56,12 @@ copy_labels <- function(df_new, df_origin = NULL) {
 
       # get var-labels of original data frame, and select only those
       # labels from variables that appear in the new (subsetted) data frame
-      df_new <- set_label(df_new, label = get_label(df_origin[, cn]))
+      df_new <- sjlabelled::set_label(df_new, label = sjlabelled::get_label(df_origin[, cn]))
 
       # same for value labels
-      df_new <- suppressMessages(set_labels(
+      df_new <- suppressMessages(sjlabelled::set_labels(
         df_new,
-        labels = get_labels(
+        labels = sjlabelled::get_labels(
           df_origin[, cn],
           attr.only = TRUE,
           include.values = "n",
