@@ -41,16 +41,17 @@
 #'   descr(e16sex, c172code, e17age, c160age)
 #'
 #' # or even use select-helpers
-#' descr(efc, ~contains("cop"), max.length = 20)
+#' descr(efc, contains("cop"), max.length = 20)
 #'
 #' @importFrom tibble as_tibble rownames_to_column
 #' @importFrom dplyr select mutate
 #' @importFrom psych describe
+#' @importFrom sjlabelled copy_labels
 #' @export
 descr <- function(x, ..., max.length = NULL) {
 
   # get dot data
-  dd <- get_dot_data(x, match.call(expand.dots = FALSE)$`...`)
+  dd <- get_dot_data(x, dplyr::quos(...))
 
   # do we have a grouped data frame?
   if (inherits(dd, "grouped_df")) {
@@ -59,7 +60,7 @@ descr <- function(x, ..., max.length = NULL) {
     # now plot everything
     for (i in seq_len(nrow(grps))) {
       # copy back labels to grouped data frame
-      tmp <- copy_labels(grps$data[[i]], dd)
+      tmp <- sjlabelled::copy_labels(grps$data[[i]], dd)
       # print title for grouping
       cat(sprintf("\nGrouped by:\n%s\n", get_grouped_title(dd, grps, i, sep = "\n")))
       # print frequencies
@@ -84,13 +85,14 @@ descr_helper <- function(dd, max.length) {
   else
     dv <- dd
 
+
   # call psych::describe and convert to tibble, remove some unnecessary
   # columns and and a variable label column
-  x <- tibble::as_tibble(psych::describe(dd)) %>%
+  x <- tibble::as_tibble(psych::describe(dd, fast = FALSE)) %>%
     tibble::rownames_to_column(var = "variable") %>%
-    dplyr::select_("-vars", "-mad") %>%
+    dplyr::select(-.data$vars, -.data$mad) %>%
     dplyr::mutate(
-      label = unname(get_label(dd, def.value = var.name)),
+      label = unname(sjlabelled::get_label(dd, def.value = var.name)),
       NA.prc = purrr::map_dbl(dv, ~ 100 * sum(is.na(.x)) / length(.x))
     ) %>%
     var_rename(median = "md")
