@@ -55,18 +55,20 @@
 #'
 #' # with select-helpers: all variables from the COPE-Index
 #' # (which all have a "cop" in their name)
-#' frq(efc, ~contains("cop"))
+#' frq(efc, contains("cop"))
 #'
 #' # all variables from column "c161sex" to column "c175empl"
 #' frq(efc, c161sex:c175empl)
 #'
 #' @importFrom stats na.omit
 #' @importFrom dplyr full_join
+#' @importFrom tibble add_row
+#' @importFrom sjlabelled get_label get_labels get_values copy_labels
 #' @export
 frq <- function(x, ..., sort.frq = c("none", "asc", "desc"), weight.by = NULL) {
 
   # get dot data
-  x <- get_dot_data(x, match.call(expand.dots = FALSE)$`...`)
+  x <- get_dot_data(x, dplyr::quos(...))
 
   # match args
   sort.frq <- match.arg(sort.frq)
@@ -82,7 +84,7 @@ frq <- function(x, ..., sort.frq = c("none", "asc", "desc"), weight.by = NULL) {
     # now plot everything
     for (i in seq_len(nrow(grps))) {
       # copy back labels to grouped data frame
-      tmp <- copy_labels(grps$data[[i]], x)
+      tmp <- sjlabelled::copy_labels(grps$data[[i]], x)
 
       # print title for grouping
       cat(sprintf("\nGrouped by:\n%s\n\n", get_grouped_title(x, grps, i, sep = "\n")))
@@ -96,7 +98,6 @@ frq <- function(x, ..., sort.frq = c("none", "asc", "desc"), weight.by = NULL) {
       dataframes[[length(dataframes) + 1]] <- dummy
     }
   } else {
-
     # if we don't have data frame, coerce
     if (!is.data.frame(x)) x <- tibble::tibble(x)
 
@@ -119,39 +120,39 @@ frq <- function(x, ..., sort.frq = c("none", "asc", "desc"), weight.by = NULL) {
 frq_helper <- function(x, sort.frq, weight.by) {
   # convert NaN and Inf to missing
   x <- zap_inf(x)
-  #---------------------------------------------------
+
   # variable with only mising?
-  #---------------------------------------------------
   if (length(stats::na.omit(x)) == 0) {
-    mydat <- data.frame(val = NA,
-                        label = NA,
-                        frq = NA,
-                        raw.prc = NA,
-                        valid.prc = NA,
-                        cum.perc = NA)
+    mydat <- data.frame(
+      val = NA,
+      label = NA,
+      frq = NA,
+      raw.prc = NA,
+      valid.prc = NA,
+      cum.perc = NA
+    )
     return(structure(class = "sjmisc.frq", list(mydat = mydat)))
   }
-  #---------------------------------------------------
+
   # get value labels (if any)
-  #---------------------------------------------------
-  labels <- get_labels(x, attr.only = T, include.values = "n", include.non.labelled = T)
-  #---------------------------------------------------
+  labels <- sjlabelled::get_labels(x, attr.only = T, include.values = "n", include.non.labelled = T)
+
   # get variable label (if any)
-  #---------------------------------------------------
-  varlab <- get_label(x)
-  #---------------------------------------------------
+  varlab <- sjlabelled::get_label(x)
+
   # do we have a labelled vector?
-  #---------------------------------------------------
   if (!is.null(labels)) {
     # add rownames and values as columns
     dat <- data.frame(n = names(labels), v = as.character(labels), stringsAsFactors = FALSE)
     colnames(dat) <- c("val", "label")
+
     # character vectors need to be converted with to_value
     # to avoid NAs, but only if character is non-numeric
     if (is.character(dat$val) && anyNA(suppressWarnings(as.numeric(dat$val))))
       dat$val <- to_value(dat$val, keep.labels = F)
     else
       dat$val <- as.numeric(dat$val)
+
     # weight data?
     if (!is.null(weight.by)) {
       dat2 <- data.frame(round(
@@ -169,8 +170,10 @@ frq_helper <- function(x, sort.frq, weight.by) {
     }
     colnames(dat2) <- c("val", "frq")
     dat2$val <- to_value(dat2$val, keep.labels = F)
+
     # join frq table and label columns
     mydat <- suppressMessages(dplyr::full_join(dat, dat2))
+
     # replace NA with 0, for proper percentages, i.e.
     # missing values don't appear (zero counts)
     mydat$frq <- suppressMessages(replace_na(mydat$frq, value = 0))
@@ -194,46 +197,58 @@ frq_helper <- function(x, sort.frq, weight.by) {
     # add values as label
     mydat$label <- labels <- as.character(mydat$val)
   }
-  #---------------------------------------------------
+
   # need numeric
-  #---------------------------------------------------
   if (is.factor(x) || is.character(x)) {
     x <- to_value(x, keep.labels = F)
   }
+
+  # check if we have any NA-values - if not, add row for NA's
+  if (!anyNA(mydat$val)) {
+    mydat <- tibble::add_row(
+      mydat,
+      val = NA,
+      label = NA,
+      frq = 0
+    )
+  }
+
   # valid values are one row less, because last row is NA row
   valid.vals <- nrow(mydat) - 1
-  # --------------------------------------------------------
+
   # sort categories ascending or descending
-  # --------------------------------------------------------
   if (!is.null(sort.frq) && (sort.frq == "asc" || sort.frq == "desc")) {
     ord <- order(mydat$frq[seq_len(valid.vals)], decreasing = (sort.frq == "desc"))
     mydat <- mydat[c(ord, valid.vals + 1), ]
     # not needed here?
     labels <- labels[ord]
   }
+
   # raw percentages
   mydat$raw.prc <- mydat$frq / sum(mydat$frq)
+
   # compute valud and cumulative percentages
   mydat$valid.prc <- c(mydat$frq[seq_len(valid.vals)] / length(stats::na.omit(x)), NA)
   mydat$cum.prc <- c(cumsum(mydat$valid.prc[seq_len(valid.vals)]), NA)
+
   # proper rounding
   mydat$raw.prc <- 100 * round(mydat$raw.prc, 4)
   mydat$cum.prc <- 100 * round(mydat$cum.prc, 4)
   mydat$valid.prc <- 100 * round(mydat$valid.prc, 4)
-  # -------------------------------------
-  # "rename" NA values
-  # -------------------------------------
+
+  # "rename" labels for NA values
   if (!is.null(mydat$label)) mydat$label[is.na(mydat$label)] <- "NA"
-  mydat$val <- suppressMessages(replace_na(mydat$val, value = max(to_value(mydat$val), na.rm = T) + 1))
+
   # save original order
   reihe <- to_value(mydat$val, start.at = 1, keep.labels = F)
-  # sort for x-axis
+
+  # sort
   if (sort.frq == "none") mydat <- mydat[order(reihe), ]
+
   # add variable label as attribute, for print-method
   attr(mydat, "label") <- varlab
-  # -------------------------------------
+
   # return results
-  # -------------------------------------
   class(mydat) <- c("sjmisc.frq", "data.frame")
   mydat
 }
@@ -242,16 +257,24 @@ frq_helper <- function(x, sort.frq, weight.by) {
 get_grouped_title <- function(x, grps, i, sep = "\n") {
   # prepare title for group
   var.name <- colnames(grps)[1]
-  t1 <- get_label(x[[var.name]], def.value = var.name)
-  t2 <- get_labels(x[[var.name]])[grps[[var.name]][i]]
+
+  # find position of value labels for current group
+  lab.pos <- which(sjlabelled::get_values(x[[var.name]]) == grps[[var.name]][i])
+
+  t1 <- sjlabelled::get_label(x[[var.name]], def.value = var.name)
+  t2 <- sjlabelled::get_labels(x[[var.name]])[lab.pos]
   title <- sprintf("%s: %s", t1, t2)
 
   # do we have another groupng variable?
   if (length(attr(x, "vars", exact = T)) > 1) {
     # prepare title for group
     var.name <- colnames(grps)[2]
-    t1 <- get_label(x[[var.name]], def.value = var.name)
-    t2 <- get_labels(x[[var.name]])[grps[[var.name]][i]]
+
+    # find position of value labels for current group
+    lab.pos <- which(sjlabelled::get_values(x[[var.name]]) == grps[[var.name]][i])
+
+    t1 <- sjlabelled::get_label(x[[var.name]], def.value = var.name)
+    t2 <- sjlabelled::get_labels(x[[var.name]])[lab.pos]
     title <- sprintf("%s%s%s: %s", title, sep, t1, t2)
   }
 
@@ -261,7 +284,7 @@ get_grouped_title <- function(x, grps, i, sep = "\n") {
 
 
 #' @importFrom tidyr nest
-#' @importFrom dplyr select_ filter
+#' @importFrom dplyr filter
 #' @importFrom stats complete.cases
 get_grouped_data <- function(x) {
   # nest data frame
@@ -269,7 +292,7 @@ get_grouped_data <- function(x) {
 
   # remove NA category
   cc <- grps %>%
-    dplyr::select_("-data") %>%
+    dplyr::select(-.data$data) %>%
     stats::complete.cases()
   # select only complete cases
   grps <- grps %>% dplyr::filter(cc)
