@@ -39,8 +39,7 @@
 #' @export
 std <- function(x, ..., include.fac = TRUE, append = FALSE, suffix = "_z") {
   # evaluate arguments, generate data
-  .dots <- match.call(expand.dots = FALSE)$`...`
-  .dat <- get_dot_data(x, .dots)
+  .dat <- get_dot_data(x, dplyr::quos(...))
 
   std_and_center(x, .dat, include.fac, append, standardize = TRUE, suffix)
 }
@@ -50,8 +49,7 @@ std <- function(x, ..., include.fac = TRUE, append = FALSE, suffix = "_z") {
 #' @export
 center <- function(x, ..., include.fac = TRUE, append = FALSE, suffix = "_c") {
   # evaluate arguments, generate data
-  .dots <- match.call(expand.dots = FALSE)$`...`
-  .dat <- get_dot_data(x, .dots)
+  .dat <- get_dot_data(x, dplyr::quos(...))
 
   std_and_center(x, .dat, include.fac, append, standardize = FALSE, suffix)
 }
@@ -103,15 +101,20 @@ std_helper <- function(x, include.fac, standardize) {
     else
       return(x)
   }
+
   # remove missings
   tmp <- stats::na.omit(x)
+
   # save value label, if any
-  lab <- get_label(x)
+  lab <- sjlabelled::get_label(x)
+
   # now center and standardize
   tmp <- tmp - mean(tmp)
   if (standardize) tmp <- tmp / stats::sd(tmp)
+
   # and fill in values in original vector
   x[!is.na(x)] <- tmp
+
   # add back label
-  set_label(x, label = lab)
+  sjlabelled::set_label(x, label = lab)
 }
